@@ -23,7 +23,12 @@
 #' occ_search(catalogNumber=c("49366","Bird.27847588"))
 #' 
 #' # Get all data, not just lat/long and name
-#' occ_search(datasetKey='7b5d6a48-f762-11e1-a439-00145eb45e9a', minimal=FALSE)
+#' occ_search(taxonKey=key, fields='all')
+#' 
+#' # Or get specific fields. Note that this isn't done on GBIF's side of things. This
+#' # is done in R, but before you get the return object, so other fields are garbage
+#' # collected
+#' occ_search(taxonKey=key, fields=c('name','basisOfRecord','protocol'))
 #' 
 #' # Use paging parameters (limit and start) to page. Note the different results 
 #' # for the two queries below.
@@ -43,7 +48,7 @@
 #' 
 #' # Taxonomic hierarchy data
 #' ## If return='meta' the output is a list of the hierarch for each record
-#' occ_search(taxonKey=key, limit=20, return='hier')
+#' occ_search(taxonKey=key, return='hier')
 #' 
 #' # Search by collector name
 #' occ_search(collectorName="smith")
@@ -52,6 +57,7 @@
 #' occ_search(collectorName=c("smith","BJ Stacey"))
 #' 
 #' # Pass in curl options for extra fun
+#' library(httr)
 #' occ_search(taxonKey=key, limit=20, return='hier', callopts=verbose())
 #' 
 #' # Search for many species
@@ -70,15 +76,12 @@
 #' 
 #' # Search on country
 #' occ_search(country='US')
-#' 
-#' # Search on publishingCountry
-#' occ_search(country='DE')
-#' 
+#'
 #' # Get only occurrences with lat/long data (i.e. georeferenced)
 #' occ_search(taxonKey=key, georeferenced=TRUE)
 #' 
 #' # Get only occurrences that were recorded as living specimens
-#' occ_search(taxonKey=key, basisOfRecord="LIVING_SPECIMEN")
+#' occ_search(taxonKey=key, basisOfRecord="LIVING_SPECIMEN", georeferenced=TRUE)
 #' 
 #' # Get occurrences for a particular date
 #' occ_search(taxonKey=key, date="2013")
@@ -91,7 +94,7 @@
 #' 
 #' # Get occurrences based on altitude
 #' key <- name_backbone(name='Puma concolor', kingdom='animals')$speciesKey
-#' occ_search(taxonKey=key, altitude=2000)
+#' occ_search(taxonKey=key, altitude=2000, georeferenced=TRUE)
 #' 
 #' # Get occurrences based on institutionCode
 #' occ_search(institutionCode="TLMF")
@@ -121,7 +124,7 @@ occ_search <- function(taxonKey=NULL, country=NULL, publishingCountry=NULL, geor
   catalogNumber=NULL, year=NULL, month=NULL, latitude=NULL, longitude=NULL, 
   altitude=NULL, depth=NULL, institutionCode=NULL, collectionCode=NULL, 
   spatialIssues=NULL, search=NULL, callopts=list(), limit=20, start=NULL, 
-  minimal=TRUE, return='all')
+  fields = 'minimal', return='all')
 {
   url = 'http://api.gbif.org/v0.9/occurrence/search'
   getdata <- function(x=NULL, itervar=NULL)
@@ -134,8 +137,8 @@ occ_search <- function(taxonKey=NULL, country=NULL, publishingCountry=NULL, geor
        basisOfRecord=basisOfRecord, datasetKey=datasetKey, date=date, catalogNumber=catalogNumber,
        year=year, month=month, latitude=latitude, longitude=longitude, 
        altitude=altitude, depth=depth, institutionCode=institutionCode, 
-       collectionCode=collectionCode, spatialIssues=spatialIssues, q=search, limit=limit, 
-       offset=start))
+       collectionCode=collectionCode, spatialIssues=spatialIssues, q=search, 
+       limit=as.integer(limit), offset=start))
     iter <- 0
     sumreturned <- 0
     outout <- list()
@@ -148,10 +151,11 @@ occ_search <- function(taxonKey=NULL, country=NULL, publishingCountry=NULL, geor
       sumreturned <- sumreturned + numreturned
       
       if(tt$count < limit)
-        sumreturned <- 999999
+        limit <- tt$count
+#         sumreturned <- 999999999
       
       if(sumreturned < limit){
-        args$limit <- limit-numreturned
+        args$limit <- limit-sumreturned
         args$offset <- sumreturned
       }
       outout[[iter]] <- tt
@@ -168,7 +172,8 @@ occ_search <- function(taxonKey=NULL, country=NULL, publishingCountry=NULL, geor
         paste("no data found, try a different search")
       } else
       {
-        data <- gbifparser(input=data, minimal=minimal)
+#         data <- gbifparser(input=data, minimal=minimal)
+        data <- gbifparser(input=data, fields=fields)
         ldfast(lapply(data, "[[", "data"))
       }
     } else
@@ -177,8 +182,9 @@ occ_search <- function(taxonKey=NULL, country=NULL, publishingCountry=NULL, geor
         paste("no data found, try a different search")
       } else
       {
-        data <- gbifparser(input=data, minimal=minimal)
-        unique(lapply(data, "[[", "hierarch"))
+#         data <- gbifparser(input=data, minimal=minimal)
+        data <- gbifparser(input=data, fields=fields)
+        unique(lapply(data, "[[", "hierarchy"))
       }
     } else
     if(return=='meta'){ 
@@ -190,9 +196,10 @@ occ_search <- function(taxonKey=NULL, country=NULL, publishingCountry=NULL, geor
         hier2 <- paste("no data found, try a different search")
       } else
       {
-        data <- gbifparser(input=data, minimal=minimal)
+#         data <- gbifparser(input=data, minimal=minimal)
+        data <- gbifparser(input=data, fields=fields)
         dat2 <- ldfast(lapply(data, "[[", "data"))
-        hier2 <- unique(lapply(data, "[[", "hierarch"))
+        hier2 <- unique(lapply(data, "[[", "hierarchy"))
       }
       list(meta=meta, hierarchy=hier2, data=dat2)
     }
@@ -200,9 +207,10 @@ occ_search <- function(taxonKey=NULL, country=NULL, publishingCountry=NULL, geor
   
   params <- list(taxonKey=taxonKey,datasetKey=datasetKey,catalogNumber=catalogNumber,
                  collectorName=collectorName,geometry=geometry,country=country,
-                 search=search,institutionCode=institutionCode,collectionCode=collectionCode)
+                 search=search,institutionCode=institutionCode,collectionCode=collectionCode,
+                 latitude=latitude,longitude=longitude)
   if(!any(sapply(params, length)>0))
-    stop("at least one of the parmaters taxonKey, datasetKey, catalogNumber, collectorName, or geometry 
+    stop("at least one of the parmaters taxonKey, datasetKey, catalogNumber, collectorName, geometry, latitude, or longitude 
          must have a value")
   iter <- params[which(sapply(params, length)>1)]
   if(length(names(iter))>1)
