@@ -3,7 +3,7 @@
 #' @template all
 #' @import httr
 #' @import plyr
-#' @import RJSONIO
+#' @importFrom RJSONIO toJSON
 #' @param scientificname A character vector of scientific names.
 #' @return A \code{data.frame} containing fields extracted from parsed 
 #' taxon names. Fields returned are the union of fields extracted from
@@ -17,11 +17,11 @@
 #'              'Vanessa atalanta (Linnaeus, 1758)'))
 #' }
 parsenames <- function(scientificname) {
-  u <- "http://apidev.gbif.org/parser/name"
-  tt <- POST('http://apidev.gbif.org/parser/name',
-                      config=c(add_headers('Content-Type' = 
-                                             'application/json')),
-                      body=RJSONIO::toJSON(scientificname))
+  url <- "http://api.gbif.org/v0.9/parser/name"
+  tt <- POST(url,
+             config=c(add_headers('Content-Type' = 
+                                    'application/json')),
+             body=RJSONIO::toJSON(scientificname))
   stop_for_status(tt)
   res <- content(tt)
   do.call(rbind.fill, lapply(res, as.data.frame))
